USB Test and Measurement Class (USBTMC) implementation in python using PyUSB
=================================================
A generic (i.e. non-specific) implementation of a USBTMC host client software to talk to USB devices implementing the USBTMC class.

